<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation type="unfinished">Program</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation type="unfinished">Na &amp;radnu površinu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation type="unfinished">&amp;Sve radne površine</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation type="unfinished">Radna površina &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation type="unfinished">&amp;Na trenutnu radnu površinu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation type="unfinished">&amp;Obnovi</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation type="unfinished">Uvijek na &amp;vrhu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation type="unfinished">&amp;Normalno</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation type="unfinished">Uvijek na &amp;dnu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zatvori</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation type="unfinished">Grupa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation type="unfinished">Zatvori grupu</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished">Postavke upravitelja zadacima</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished">Općenito</translation>
    </message>
    <message>
        <source>Show only windows from c&amp;urrent desktop</source>
        <translation type="obsolete">Pokaži samo prozore sa t&amp;renutne radne površine</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished">Grupiranje prozora</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation type="unfinished">Izgled</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation type="unfinished"> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation type="unfinished">Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation type="unfinished">Samo ikona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation type="unfinished">Samo tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
